@@ -1,3 +1,9 @@
+/*
+  SPDX-FileCopyrightText: 2016 David Faure <faure@kde.org>
+
+  SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
 #include "dummykernel.h"
 
 #include <Akonadi/ChangeRecorder>
@@ -26,7 +32,6 @@ DummyKernel::DummyKernel(QObject *parent)
     mCollectionModel->setSourceModel(mEntityTreeModel);
     mCollectionModel->addMimeTypeInclusionFilter(Akonadi::Collection::mimeType());
     mCollectionModel->setHeaderGroup(Akonadi::EntityTreeModel::CollectionTreeHeaders);
-    mCollectionModel->setDynamicSortFilter(true);
     mCollectionModel->setSortCaseSensitivity(Qt::CaseInsensitive);
 }
 
