@@ -1,11 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2016-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
-
+#include "mailcommon_private_export.h"
 #include <QDialog>
 
 namespace KIdentityManagementWidgets
@@ -14,7 +14,7 @@ class IdentityCombo;
 }
 namespace MailCommon
 {
-class FilterActionMissingIdentityDialog : public QDialog
+class MAILCOMMON_TESTS_EXPORT FilterActionMissingIdentityDialog : public QDialog
 {
     Q_OBJECT
 public:
@@ -23,8 +23,8 @@ public:
     [[nodiscard]] int selectedIdentity() const;
 
 private:
-    void writeConfig();
-    void readConfig();
+    MAILCOMMON_NO_EXPORT void writeConfig();
+    MAILCOMMON_NO_EXPORT void readConfig();
     KIdentityManagementWidgets::IdentityCombo *mComboBoxIdentity = nullptr;
 };
 }
