@@ -1,16 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2016-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
 
+#include "mailcommon_private_export.h"
 #include <QDialog>
 class QListWidget;
 namespace MailCommon
 {
-class FilterActionMissingTagDialog : public QDialog
+class MAILCOMMON_TESTS_EXPORT FilterActionMissingTagDialog : public QDialog
 {
     Q_OBJECT
 public:
@@ -22,9 +23,9 @@ public:
     [[nodiscard]] QString selectedTag() const;
 
 private:
-    void slotAddTag();
-    void readConfig();
-    void writeConfig();
+    MAILCOMMON_NO_EXPORT void slotAddTag();
+    MAILCOMMON_NO_EXPORT void readConfig();
+    MAILCOMMON_NO_EXPORT void writeConfig();
 
     enum TypeData {
         UrlData = Qt::UserRole + 1
