@@ -8,7 +8,7 @@
 #pragma once
 
 #include "filteraction.h"
-
+#include "mailcommon_private_export.h"
 namespace MailCommon
 {
 /**
@@ -25,7 +25,7 @@ namespace MailCommon
  * @author Marc Mutz <mutz@kde.org>, based upon work by Stefan Taferner <taferner@kde.org>
  * @see FilterAction Filter
  */
-class FilterActionWithString : public FilterAction
+class MAILCOMMON_TESTS_EXPORT FilterActionWithString : public FilterAction
 {
     Q_OBJECT
 public:
