@@ -24,7 +24,7 @@ KMFilterAccountList::KMFilterAccountList(QWidget *parent)
     const QStringList headerNames{i18n("Account Name"), i18n("Type")};
     setHeaderItem(new QTreeWidgetItem(headerNames));
     setAllColumnsShowFocus(true);
-    setFrameStyle(QFrame::WinPanel + QFrame::Sunken);
+    setFrameStyle(QFrame::WinPanel | QFrame::Sunken);
     setSortingEnabled(false);
     setRootIsDecorated(false);
     setSortingEnabled(true);
@@ -34,11 +34,27 @@ KMFilterAccountList::KMFilterAccountList(QWidget *parent)
 
 KMFilterAccountList::~KMFilterAccountList() = default;
 
-void KMFilterAccountList::updateAccountList(MailCommon::MailFilter *filter)
+void KMFilterAccountList::reloadAndSelectAccountsFrom(const MailCommon::MailFilter *filter)
+{
+    const auto decideSelected = [filter](const QString &accountName) {
+        return filter && filter->applyOnAccount(accountName);
+    };
+    reloadAndSelectAccountsInternal(decideSelected);
+}
+
+void KMFilterAccountList::reloadAndSelectAccounts(const QStringList &selectedAccounts)
+{
+    const auto decideSelected = [&selectedAccounts](const QString &accountName) {
+        return selectedAccounts.contains(accountName);
+    };
+    reloadAndSelectAccountsInternal(decideSelected);
+}
+
+void KMFilterAccountList::reloadAndSelectAccountsInternal(const std::function<bool(const QString &)> &decideSelected)
 {
     clear();
 
-    QTreeWidgetItem *top = nullptr;
+    QTreeWidgetItem *prev = nullptr;
     // Block the signals here, otherwise we end up calling
     // slotApplicableAccountsChanged(), which will read the incomplete item
     // state and write that back to the filter
@@ -47,14 +63,12 @@ void KMFilterAccountList::updateAccountList(MailCommon::MailFilter *filter)
     const int nbAccount = lst.count();
     for (int i = 0; i < nbAccount; ++i) {
         const Akonadi::AgentInstance agent = lst.at(i);
-        auto listItem = new QTreeWidgetItem(this, top);
+        auto listItem = new QTreeWidgetItem(this, prev);
         listItem->setText(0, agent.name());
         listItem->setText(1, agent.type().name());
         listItem->setText(2, agent.identifier());
-        if (filter) {
-            listItem->setCheckState(0, filter->applyOnAccount(agent.identifier()) ? Qt::Checked : Qt::Unchecked);
-        }
-        top = listItem;
+        listItem->setCheckState(0, decideSelected(agent.identifier()) ? Qt::Checked : Qt::Unchecked);
+        prev = listItem;
     }
     blockSignals(false);
 
@@ -63,68 +77,24 @@ void KMFilterAccountList::updateAccountList(MailCommon::MailFilter *filter)
     resizeColumnToContents(0);
     resizeColumnToContents(1);
 
-    top = topLevelItem(0);
+    QTreeWidgetItem *top = topLevelItem(0);
     if (top) {
         setCurrentItem(top);
     }
 }
 
-void KMFilterAccountList::applyOnAccount(MailCommon::MailFilter *filter)
+QStringList KMFilterAccountList::selectedAccounts() const
 {
-    QTreeWidgetItemIterator it(this);
+    QStringList accounts;
 
-    while (QTreeWidgetItem *item = *it) {
-        const QString id = item->text(2);
-        filter->setApplyOnAccount(id, item->checkState(0) == Qt::Checked);
-        ++it;
-    }
-}
-
-void KMFilterAccountList::applyOnAccount(const QStringList &lstAccount)
-{
-    clear();
-
-    QTreeWidgetItem *top = nullptr;
-    // Block the signals here, otherwise we end up calling
-    // slotApplicableAccountsChanged(), which will read the incomplete item
-    // state and write that back to the filter
-    blockSignals(true);
-    const Akonadi::AgentInstance::List lst = MailCommon::Util::agentInstances();
-    const int nbAccount = lst.count();
-    for (int i = 0; i < nbAccount; ++i) {
-        const Akonadi::AgentInstance agent = lst.at(i);
-        auto listItem = new QTreeWidgetItem(this, top);
-        listItem->setText(0, agent.name());
-        listItem->setText(1, agent.type().name());
-        listItem->setText(2, agent.identifier());
-        listItem->setCheckState(0, lstAccount.contains(agent.identifier()) ? Qt::Checked : Qt::Unchecked);
-        top = listItem;
-    }
-    blockSignals(false);
-
-    // make sure our hidden column is really hidden (Qt tends to re-show it)
-    hideColumn(2);
-    resizeColumnToContents(0);
-    resizeColumnToContents(1);
-
-    top = topLevelItem(0);
-    if (top) {
-        setCurrentItem(top);
-    }
-}
-
-QStringList KMFilterAccountList::selectedAccount()
-{
-    QStringList lstAccount;
-    QTreeWidgetItemIterator it(this);
-
-    while (QTreeWidgetItem *item = *it) {
+    const int count = topLevelItemCount();
+    for (int i = 0; i < count; ++i) {
+        QTreeWidgetItem *item = topLevelItem(i);
         if (item->checkState(0) == Qt::Checked) {
-            lstAccount << item->text(2);
+            accounts.append(item->text(2));
         }
-        ++it;
     }
-    return lstAccount;
+    return accounts;
 }
 
 #include "moc_kmfilteraccountlist.cpp"
