@@ -6,9 +6,6 @@
 
 #include "searchruledate.h"
 
-#include "filter/filterlog.h"
-using MailCommon::FilterLog;
-
 #include <KLocalizedString>
 #include <KMime/Message>
 using namespace MailCommon;
@@ -37,13 +34,9 @@ bool SearchRuleDate::matches(const Akonadi::Item &item) const
 
     const QDate msgDate = msg->date()->dateTime().date();
     const QDate dateValue = QDate::fromString(contents(), Qt::ISODate);
-    bool rc = matchesInternal(dateValue, msgDate);
-    if (FilterLog::instance()->isLogging()) {
-        QString msg = (rc ? QStringLiteral("<font color=#00FF00>1 = </font>") : QStringLiteral("<font color=#FF0000>0 = </font>"));
-        msg += FilterLog::recode(asString());
-        msg += QLatin1StringView(" ( <i>") + contents() + QLatin1StringView("</i> )"); // TODO change with locale?
-        FilterLog::instance()->add(msg, FilterLog::RuleResult);
-    }
+    const bool rc = matchesInternal(dateValue, msgDate);
+
+    maybeLogMatchResult(rc);
     return rc;
 }
 
